Scenario: Gain access to a remote secret service that is hidden behind a firewall
=================================================================================

Requirements:
```
Given you have a remote SSH account and forwarding allowed on remote host
```
